# Generated by Django 3.2.2 on 2021-05-08 10:15

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = [
    ]

    operations = [
        migrations.CreateModel(
            name='Platform',
            fields=[
                ('platform_id', models.IntegerField(primary_key=True, serialize=False, verbose_name='平台ID')),
                ('platform_name', models.CharField(max_length=128, verbose_name='平台名称')),
            ],
        ),
    ]
