# Generated by Django 3.2.2 on 2021-05-09 15:00

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='BaseInfo',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('platform_uid', models.BigIntegerField(db_index=True, verbose_name='平台用户ID')),
                ('user_name', models.CharField(blank=True, db_index=True, max_length=128, null=True, verbose_name='用户名')),
                ('full_name', models.CharField(blank=True, max_length=128, null=True, verbose_name='姓名')),
                ('phone', models.CharField(blank=True, db_index=True, max_length=128, null=True, verbose_name='手机')),
                ('email', models.EmailField(blank=True, db_index=True, max_length=254, null=True, verbose_name='邮箱')),
                ('wechat', models.CharField(blank=True, db_index=True, max_length=128, null=True, verbose_name='微信号')),
                ('user_info', models.JSONField(blank=True, null=True, verbose_name='用户信息')),
                ('platform', models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='xj_user.platform')),
            ],
            options={
                'verbose_name': '用户基本信息表',
                'db_table': 'user_base_info',
                'unique_together': {('platform', 'user_name'), ('platform', 'platform_uid')},
            },
        ),
    ]
