# Generated by Django 3.2.2 on 2021-05-11 04:50

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0002_baseinfo'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='baseinfo',
            options={'verbose_name_plural': '用户基础信息表'},
        ),
        migrations.AlterModelOptions(
            name='platform',
            options={'verbose_name_plural': '平台基础信息表'},
        ),
        migrations.AlterField(
            model_name='baseinfo',
            name='platform',
            field=models.ForeignKey(on_delete=django.db.models.deletion.DO_NOTHING, to='xj_user.platform', verbose_name='平台ID'),
        ),
        migrations.AlterField(
            model_name='platform',
            name='platform_id',
            field=models.IntegerField(help_text='必填。不自动生成，由运营人员统一设置。', primary_key=True, serialize=False, verbose_name='平台ID'),
        ),
        migrations.AlterField(
            model_name='platform',
            name='platform_name',
            field=models.CharField(help_text='必填。平台名称可以是中文、英文、俄文等。', max_length=128, verbose_name='平台名称'),
        ),
    ]
