# Generated by Django 3.2.5 on 2022-02-05 05:25

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0005_merge_0004_auto_20220101_1450_0004_auto_20220101_1707'),
        ('xj_user', '0006_auto_20220205_1300'),
    ]

    operations = [
    ]
