# Generated by Django 3.2.5 on 2022-02-05 05:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0005_auth'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='auth',
            options={'verbose_name_plural': '用户认证'},
        ),
        migrations.AlterModelOptions(
            name='baseinfo',
            options={'verbose_name_plural': '账户 - 基础信息'},
        ),
        migrations.AlterModelOptions(
            name='platform',
            options={'verbose_name_plural': '交易平台'},
        ),
    ]
