# Generated by Django 3.2.5 on 2022-01-01 09:19

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0004_auto_20220101_1450'),
        ('xj_user', '0004_auto_20220101_1707'),
    ]

    operations = [
    ]
