# Generated by Django 3.2.5 on 2022-01-01 06:50

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('xj_user', '0003_auto_20210511_1250'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='baseinfo',
            options={'verbose_name_plural': '账户基础信息表'},
        ),
        migrations.AlterModelOptions(
            name='platform',
            options={'verbose_name_plural': '平台'},
        ),
    ]
